summaryrefslogtreecommitdiff
path: root/app/Fact.php
diff options
context:
space:
mode:
Diffstat (limited to 'app/Fact.php')
-rw-r--r--app/Fact.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/app/Fact.php b/app/Fact.php
index 3bd0989c55..95470d5432 100644
--- a/app/Fact.php
+++ b/app/Fact.php
@@ -15,6 +15,7 @@ namespace Fisharebest\Webtrees;
* You should have received a copy of the GNU General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
+use Fisharebest\Webtrees\Functions\FunctionsPrint;
/**
* Class Fact - Class that defines an event details object
@@ -44,7 +45,7 @@ class Fact {
/** @var Place The place of this fact, from the “2 PLAC …” attribute */
private $place;
/** @var int Temporary(!) variable Used by sort_facts() */
public $sortOrder;
/**
@@ -385,7 +386,7 @@ class Fact {
}
$date = $this->getDate();
if ($this->getTag() == 'BIRT' && $this->getParent() instanceof Individual && $this->getParent()->getTree()->getPreference('SHOW_PARENTS_AGE')) {
- $attributes[] = $date->display() . format_parents_age($this->getParent(), $date);
+ $attributes[] = $date->display() . FunctionsPrint::formatParentsAges($this->getParent(), $date);
} else {
$attributes[] = $date->display();
}
@@ -44,7 +45,7 @@ class Fact {
/** @var Place The place of this fact, from the “2 PLAC …” attribute */
private $place;
- /** @var int Temporary(!) variable Used by sort_facts() */
+ /** @var int Temporary(!) variable Used by Functions::sortFacts() */
public $sortOrder;
/**